@@ -16,23 +16,23 @@
  * Boston, MA 021110-1307, USA.
  */
 
+#include "kerncompat.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <fcntl.h>
-#include <unistd.h>
 #include <getopt.h>
 #include <limits.h>
-
-#include "kerncompat.h"
+#include <errno.h>
+#include <string.h>
 #include "kernel-shared/ctree.h"
 #include "kernel-shared/volumes.h"
 #include "kernel-shared/disk-io.h"
-#include "kernel-shared/print-tree.h"
 #include "kernel-shared/transaction.h"
-#include "kernel-lib/list.h"
-#include "kernel-lib/radix-tree.h"
+#include "kernel-shared/extent_io.h"
 #include "common/utils.h"
 #include "common/help.h"
+#include "common/extent-cache.h"
+#include "common/messages.h"
+#include "common/string-utils.h"
 
 #define FIELD_BUF_LEN 80
 
@@ -54,8 +54,7 @@ static int debug_corrupt_block(struct extent_buffer *eb,
 				ret = -EIO;
 			if (ret < 0) {
 				errno = -ret;
-				error("cannot read eb bytenr %llu: %m",
-					(unsigned long long)eb->start);
+				error("cannot read eb bytenr %llu: %m", eb->start);
 				return ret;
 			}
 			printf("corrupting %llu copy %d\n", eb->start,
@@ -64,8 +63,7 @@ static int debug_corrupt_block(struct extent_buffer *eb,
 			ret = write_and_map_eb(eb->fs_info, eb);
 			if (ret < 0) {
 				errno = -ret;
-				error("cannot write eb bytenr %llu: %m",
-					(unsigned long long)eb->start);
+				error("cannot write eb bytenr %llu: %m", eb->start);
 				return ret;
 			}
 		}
@@ -153,7 +151,7 @@ static void corrupt_keys(struct btrfs_trans_handle *trans,
 
 	fprintf(stderr,
 		"corrupting keys in block %llu slot %d swapping with %d\n",
-		(unsigned long long)eb->start, slot, bad_slot);
+		eb->start, slot, bad_slot);
 
 	if (btrfs_header_level(eb) == 0) {
 		btrfs_item_key(eb, &bad_key, bad_slot);
@@ -486,7 +484,7 @@ static int corrupt_block_group(struct btrfs_root *root, u64 bg, char *field)
 
 	corrupt_field = convert_block_group_field(field);
 	if (corrupt_field == BTRFS_BLOCK_GROUP_ITEM_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -497,9 +495,10 @@ static int corrupt_block_group(struct btrfs_root *root, u64 bg, char *field)
 	trans = btrfs_start_transaction(root, 1);
 	if (IS_ERR(trans)) {
 		btrfs_free_path(path);
-		fprintf(stderr, "Couldn't start transaction %ld\n",
-			PTR_ERR(trans));
-		return PTR_ERR(trans);
+		ret = PTR_ERR(trans);
+		errno = -ret;
+		error_msg(ERROR_MSG_START_TRANS, "%m");
+		return ret;
 	}
 
 	key.objectid = bg;
@@ -508,14 +507,14 @@ static int corrupt_block_group(struct btrfs_root *root, u64 bg, char *field)
 
 	ret = btrfs_search_slot(trans, root, &key, path, 0, 1);
 	if (ret < 0) {
-		fprintf(stderr, "Error searching for bg %llu %d\n", bg, ret);
+		error("error searching for bg %llu %d", bg, ret);
 		goto out;
 	}
 
 	ret = 0;
 	btrfs_item_key_to_cpu(path->nodes[0], &key, path->slots[0]);
 	if (key.type != BTRFS_BLOCK_GROUP_ITEM_KEY) {
-		fprintf(stderr, "Couldn't find the bg %llu\n", bg);
+		error("couldn't find the bg %llu", bg);
 		goto out;
 	}
 
@@ -558,7 +557,7 @@ static int corrupt_key(struct btrfs_root *root, struct btrfs_key *key,
 	int ret;
 
 	if (corrupt_field == BTRFS_KEY_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -576,7 +575,7 @@ static int corrupt_key(struct btrfs_root *root, struct btrfs_key *key,
 	if (ret < 0)
 		goto out;
 	if (ret > 0) {
-		fprintf(stderr, "Couldn't find the key to corrupt\n");
+		error("couldn't find the key to corrupt");
 		ret = -ENOENT;
 		goto out;
 	}
@@ -592,8 +591,7 @@ static int corrupt_key(struct btrfs_root *root, struct btrfs_key *key,
 		key->offset = generate_u64(key->objectid);
 		break;
 	default:
-		fprintf(stderr, "Invalid field %s, %d\n", field,
-			corrupt_field);
+		error("invalid field %s, %d", field, corrupt_field);
 		ret = -EINVAL;
 		goto out;
 	}
@@ -622,7 +620,7 @@ static int corrupt_dir_item(struct btrfs_root *root, struct btrfs_key *key,
 	int ret;
 
 	if (corrupt_field == BTRFS_DIR_ITEM_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -640,7 +638,7 @@ static int corrupt_dir_item(struct btrfs_root *root, struct btrfs_key *key,
 	if (ret) {
 		if (ret > 0)
 			ret = -ENOENT;
-		fprintf(stderr, "Error searching for dir item %d\n", ret);
+		error("error searching for dir item %d", ret);
 		goto out;
 	}
 
@@ -686,7 +684,7 @@ static int corrupt_inode(struct btrfs_trans_handle *trans,
 	int ret;
 
 	if (corrupt_field == BTRFS_INODE_FIELD_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -703,7 +701,7 @@ static int corrupt_inode(struct btrfs_trans_handle *trans,
 		goto out;
 	if (ret) {
 		if (!path->slots[0]) {
-			fprintf(stderr, "Couldn't find inode %llu\n", inode);
+			error("couldn't find inode %llu", inode);
 			ret = -ENOENT;
 			goto out;
 		}
@@ -713,7 +711,7 @@ static int corrupt_inode(struct btrfs_trans_handle *trans,
 
 	btrfs_item_key_to_cpu(path->nodes[0], &key, path->slots[0]);
 	if (key.objectid != inode) {
-		fprintf(stderr, "Couldn't find inode %llu\n", inode);
+		error("couldn't find inode %llu", inode);
 		ret = -ENOENT;
 		goto out;
 	}
@@ -789,7 +787,7 @@ static int corrupt_file_extent(struct btrfs_trans_handle *trans,
 
 	corrupt_field = convert_file_extent_field(field);
 	if (corrupt_field == BTRFS_FILE_EXTENT_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -805,7 +803,7 @@ static int corrupt_file_extent(struct btrfs_trans_handle *trans,
 	if (ret < 0)
 		goto out;
 	if (ret) {
-		fprintf(stderr, "Couldn't find extent %llu for inode %llu\n",
+		error("couldn't find extent %llu for inode %llu",
 			extent, inode);
 		ret = -ENOENT;
 		goto out;
@@ -821,7 +819,7 @@ static int corrupt_file_extent(struct btrfs_trans_handle *trans,
 		break;
 	case BTRFS_FILE_EXTENT_TYPE:
 		if (bogus == (u64)-1) {
-			fprintf(stderr, "Specify a new extent type value (-v)\n");
+			error("specify a new extent type value (-v)");
 			ret = -EINVAL;
 			goto out;
 		}
@@ -867,13 +865,13 @@ static int corrupt_metadata_block(struct btrfs_fs_info *fs_info, u64 block,
 
 	corrupt_field = convert_metadata_block_field(field);
 	if (corrupt_field == BTRFS_METADATA_BLOCK_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
 	eb = read_tree_block(fs_info, block, 0);
 	if (!extent_buffer_uptodate(eb)) {
-		fprintf(stderr, "Couldn't read in tree block %s\n", field);
+		error("couldn't read in tree block %s", field);
 		return -EINVAL;
 	}
 
@@ -885,12 +883,13 @@ static int corrupt_metadata_block(struct btrfs_fs_info *fs_info, u64 block,
 		u64 bogus = generate_u64(orig);
 
 		btrfs_set_header_generation(eb, bogus);
+		csum_tree_block_size(eb, fs_info->csum_size, 0,
+				     fs_info->csum_type);
 		ret = write_and_map_eb(fs_info, eb);
 		free_extent_buffer(eb);
 		if (ret < 0) {
 			errno = -ret;
-			fprintf(stderr,
-				"failed to write extent buffer at %llu: %m",
+			error("failed to write extent buffer at %llu: %m",
 				eb->start);
 			return ret;
 		}
@@ -919,8 +918,7 @@ static int corrupt_metadata_block(struct btrfs_fs_info *fs_info, u64 block,
 
 		root = btrfs_read_fs_root(fs_info, &root_key);
 		if (IS_ERR(root)) {
-			fprintf(stderr, "Couldn't find owner root %llu\n",
-				key.objectid);
+			error("couldn't find owner root %llu", key.objectid);
 			return PTR_ERR(root);
 		}
 
@@ -931,15 +929,16 @@ static int corrupt_metadata_block(struct btrfs_fs_info *fs_info, u64 block,
 		trans = btrfs_start_transaction(root, 1);
 		if (IS_ERR(trans)) {
 			btrfs_free_path(path);
-			fprintf(stderr, "Couldn't start transaction %ld\n",
-				PTR_ERR(trans));
-			return PTR_ERR(trans);
+			ret = PTR_ERR(trans);
+			errno = -ret;
+			error_msg(ERROR_MSG_START_TRANS, "%m");
+			return ret;
 		}
 
 		path->lowest_level = level;
 		ret = btrfs_search_slot(trans, root, &key, path, 0, 1);
 		if (ret < 0) {
-			fprintf(stderr, "Error searching to node %d\n", ret);
+			error("error searching to node %d", ret);
 			btrfs_free_path(path);
 			btrfs_abort_transaction(trans, ret);
 			return ret;
@@ -969,7 +968,7 @@ static int corrupt_btrfs_item(struct btrfs_root *root, struct btrfs_key *key,
 
 	corrupt_field = convert_item_field(field);
 	if (corrupt_field == BTRFS_ITEM_BAD) {
-		fprintf(stderr, "Invalid field %s\n", field);
+		error("invalid field %s", field);
 		return -EINVAL;
 	}
 
@@ -980,14 +979,15 @@ static int corrupt_btrfs_item(struct btrfs_root *root, struct btrfs_key *key,
 	trans = btrfs_start_transaction(root, 1);
 	if (IS_ERR(trans)) {
 		btrfs_free_path(path);
-		fprintf(stderr, "Couldn't start transaction %ld\n",
-			PTR_ERR(trans));
-		return PTR_ERR(trans);
+		ret = PTR_ERR(trans);
+		errno = -ret;
+		error_msg(ERROR_MSG_START_TRANS, "%m");
+		return ret;
 	}
 
 	ret = btrfs_search_slot(trans, root, key, path, 0, 1);
 	if (ret != 0) {
-		fprintf(stderr, "Error searching to node %d\n", ret);
+		error("error searching to node %d", ret);
 		goto out;
 	}
 
@@ -1028,15 +1028,15 @@ static int corrupt_btrfs_item_data(struct btrfs_root *root,
 
 	trans = btrfs_start_transaction(root, 1);
 	if (IS_ERR(trans)) {
-		fprintf(stderr, "Couldn't start transaction %ld\n",
-			PTR_ERR(trans));
 		ret = PTR_ERR(trans);
+		errno = -ret;
+		error_msg(ERROR_MSG_START_TRANS, "%m");
 		goto free_path;
 	}
 
 	ret = btrfs_search_slot(trans, root, key, path, 0, 1);
 	if (ret != 0) {
-		fprintf(stderr, "Error searching to node %d\n", ret);
+		error("error searching to node %d", ret);
 		goto commit_txn;
 	}
 	leaf = path->nodes[0];
@@ -1044,7 +1044,8 @@ static int corrupt_btrfs_item_data(struct btrfs_root *root,
 	data = btrfs_item_ptr(leaf, slot, void);
 	item_size = btrfs_item_size(leaf, slot);
 	if (bogus_offset + bogus_size > item_size) {
-		fprintf(stderr, "Item corruption past end of item: %llu > %u\n", bogus_offset + bogus_size, item_size);
+		error("item corruption past end of item: %llu > %u\n",
+			bogus_offset + bogus_size, item_size);
 		ret = -EINVAL;
 		goto commit_txn;
 	}
@@ -1072,16 +1073,17 @@ static int delete_item(struct btrfs_root *root, struct btrfs_key *key)
 	trans = btrfs_start_transaction(root, 1);
 	if (IS_ERR(trans)) {
 		btrfs_free_path(path);
-		fprintf(stderr, "Couldn't start transaction %ld\n",
-			PTR_ERR(trans));
-		return PTR_ERR(trans);
+		ret = PTR_ERR(trans);
+		errno = -ret;
+		error_msg(ERROR_MSG_START_TRANS, "%m");
+		return ret;
 	}
 
 	ret = btrfs_search_slot(trans, root, key, path, -1, 1);
 	if (ret) {
 		if (ret > 0)
 			ret = -ENOENT;
-		fprintf(stderr, "Error searching to node %d\n", ret);
+		error("error searching to node %d", ret);
 		goto out;
 	}
 	ret = btrfs_del_item(trans, root, path);
@@ -1100,14 +1102,15 @@ static int delete_csum(struct btrfs_root *root, u64 bytenr, u64 bytes)
 	root = btrfs_csum_root(root->fs_info, bytenr);
 	trans = btrfs_start_transaction(root, 1);
 	if (IS_ERR(trans)) {
-		fprintf(stderr, "Couldn't start transaction %ld\n",
-			PTR_ERR(trans));
-		return PTR_ERR(trans);
+		ret = PTR_ERR(trans);
+		errno = -ret;
+		error_msg(ERROR_MSG_START_TRANS, "%m");
+		return ret;
 	}
 
 	ret = btrfs_del_csums(trans, bytenr, bytes);
 	if (ret)
-		fprintf(stderr, "Error deleting csums %d\n", ret);
+		error("error deleting csums %d", ret);
 	btrfs_commit_transaction(trans, root);
 	return ret;
 }
@@ -1141,11 +1144,11 @@ static int corrupt_item_nocow(struct btrfs_trans_handle *trans,
 	}
 	btrfs_item_key_to_cpu(leaf, &key, slot);
 	if (del) {
-		fprintf(stdout, "Deleting key and data [%llu, %u, %llu].\n",
+		fprintf(stdout, "Deleting key and data [%llu, %u, %llu]\n",
 			key.objectid, key.type, key.offset);
 		btrfs_del_item(trans, root, path);
 	} else {
-		fprintf(stdout, "Corrupting key and data [%llu, %u, %llu].\n",
+		fprintf(stdout, "Corrupting key and data [%llu, %u, %llu]\n",
 			key.objectid, key.type, key.offset);
 		ptr = btrfs_item_ptr_offset(leaf, slot);
 		item_size = btrfs_item_size(leaf, slot);
@@ -1183,7 +1186,7 @@ static int corrupt_chunk_tree(struct btrfs_trans_handle *trans,
 	ret = btrfs_search_slot(trans, root, &key, path, 0, 0);
 	BUG_ON(ret == 0);
 	if (ret < 0) {
-		fprintf(stderr, "Error searching tree\n");
+		error("error searching tree");
 		goto free_out;
 	}
 	/* corrupt/del dev_item first */
@@ -1210,7 +1213,7 @@ static int corrupt_chunk_tree(struct btrfs_trans_handle *trans,
 	ret = btrfs_search_slot(trans, root, &key, path, 0, 0);
 	BUG_ON(ret == 0);
 	if (ret < 0) {
-		fprintf(stderr, "Error searching tree\n");
+		error("error searching tree");
 		goto free_out;
 	}
 	/* corrupt/del chunk then*/
@@ -1246,12 +1249,11 @@ static int find_chunk_offset(struct btrfs_root *root,
 	 */
 	ret = btrfs_search_slot(NULL, root, &key, path, 0, 0);
 	if (ret > 0) {
-		fprintf(stderr, "Can't find chunk with given offset %llu\n",
-			offset);
+		error("can't find chunk with given offset %llu", offset);
 		goto out;
 	}
 	if (ret < 0) {
-		fprintf(stderr, "Error searching chunk\n");
+		error("error searching chunk");
 		goto out;
 	}
 out:
@@ -1264,7 +1266,7 @@ static void parse_key(u64 *objectid, u8 *type, u64 *offset)
 
 	int ret = sscanf(optarg, "%llu,%hhu,%llu", objectid, type, offset);
 	if (ret != 3) {
-	        fprintf(stderr, "error parsing key '%s': %d\n", optarg, errno);
+	        error("error parsing key '%s': %d", optarg, errno);
 	        print_usage(1);
 	}
 }
@@ -1282,7 +1284,7 @@ static struct btrfs_root *open_root(struct btrfs_fs_info *fs_info,
 
 	root = btrfs_read_fs_root(fs_info, &root_key);
 	if (IS_ERR(root)) {
-		fprintf(stderr, "couldn't find root %llu\n", root_objectid);
+		error("couldn't find root %llu", root_objectid);
 		print_usage(1);
 	}
 
@@ -1435,12 +1437,11 @@ int main(int argc, char **argv)
 		return 1;
 	dev = argv[optind];
 
-	radix_tree_init();
 	cache_tree_init(&root_cache);
 
 	root = open_ctree(dev, 0, OPEN_CTREE_WRITES);
 	if (!root) {
-		fprintf(stderr, "Open ctree failed\n");
+		error("open ctree failed");
 		exit(1);
 	}
 	target_root = root;
@@ -1480,7 +1481,7 @@ int main(int argc, char **argv)
 		del = rand_range(3);
 		path = btrfs_alloc_path();
 		if (!path) {
-			fprintf(stderr, "path allocation failed\n");
+			error_msg(ERROR_MSG_MEMORY, NULL);
 			goto out_close;
 		}
 
@@ -1494,7 +1495,7 @@ int main(int argc, char **argv)
 		ret = corrupt_item_nocow(trans, root->fs_info->chunk_root,
 					 path, del);
 		if (ret < 0)
-			fprintf(stderr, "Failed to corrupt chunk record\n");
+			error("failed to corrupt chunk record");
 		btrfs_commit_transaction(trans, root);
 		goto out_close;
 	}
@@ -1505,7 +1506,7 @@ int main(int argc, char **argv)
 		BUG_ON(IS_ERR(trans));
 		ret = corrupt_chunk_tree(trans, root->fs_info->chunk_root);
 		if (ret < 0)
-			fprintf(stderr, "Failed to corrupt chunk tree\n");
+			error("failed to corrupt chunk tree");
 		btrfs_commit_transaction(trans, root);
 		goto out_close;
 	}
@@ -1606,9 +1607,9 @@ int main(int argc, char **argv)
 			eb = btrfs_find_create_tree_block(root->fs_info,
 					logical);
 			if (!eb) {
-				error(
-		"not enough memory to allocate extent buffer for bytenr %llu",
-					(unsigned long long)logical);
+				error_msg(ERROR_MSG_MEMORY,
+					"allocating extent buffer for bytenr %llu",
+					logical);
 				ret = 1;
 				goto out_close;
 			}
