@@ -16,24 +16,30 @@
  * Boston, MA 021110-1307, USA.
  */
 
+#include "kerncompat.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <uuid/uuid.h>
 #include <getopt.h>
 #include <fcntl.h>
-
-#include "kerncompat.h"
-#include "kernel-lib/radix-tree.h"
+#include <errno.h>
+#include <stdbool.h>
+#include <string.h>
+#include <strings.h>
+#include <uuid/uuid.h>
 #include "kernel-shared/ctree.h"
 #include "kernel-shared/disk-io.h"
 #include "kernel-shared/print-tree.h"
-#include "kernel-shared/transaction.h"
 #include "kernel-shared/volumes.h"
-#include "cmds/commands.h"
+#include "kernel-shared/extent_io.h"
+#include "common/defs.h"
+#include "common/extent-cache.h"
+#include "common/messages.h"
 #include "common/utils.h"
 #include "common/help.h"
 #include "common/device-scan.h"
+#include "common/string-utils.h"
+#include "cmds/commands.h"
 
 static void print_extents(struct extent_buffer *eb)
 {
@@ -94,35 +100,35 @@ static void print_old_roots(struct btrfs_super_block *super)
 
 	for (i = 0; i < BTRFS_NUM_BACKUP_ROOTS; i++) {
 		backup = super->super_roots + i;
-		printf("btrfs root backup slot %d\n", i);
-		printf("\ttree root gen %llu block %llu\n",
-		       (unsigned long long)btrfs_backup_tree_root_gen(backup),
-		       (unsigned long long)btrfs_backup_tree_root(backup));
+		pr_verbose(LOG_DEFAULT, "btrfs root backup slot %d\n", i);
+		pr_verbose(LOG_DEFAULT, "\ttree root gen %llu block %llu\n",
+		       btrfs_backup_tree_root_gen(backup),
+		       btrfs_backup_tree_root(backup));
 
-		printf("\t\t%s gen %llu block %llu\n", extent_tree_str,
-		       (unsigned long long)btrfs_backup_extent_root_gen(backup),
-		       (unsigned long long)btrfs_backup_extent_root(backup));
+		pr_verbose(LOG_DEFAULT, "\t\t%s gen %llu block %llu\n", extent_tree_str,
+		       btrfs_backup_extent_root_gen(backup),
+		       btrfs_backup_extent_root(backup));
 
-		printf("\t\tchunk root gen %llu block %llu\n",
-		       (unsigned long long)btrfs_backup_chunk_root_gen(backup),
-		       (unsigned long long)btrfs_backup_chunk_root(backup));
+		pr_verbose(LOG_DEFAULT, "\t\tchunk root gen %llu block %llu\n",
+		       btrfs_backup_chunk_root_gen(backup),
+		       btrfs_backup_chunk_root(backup));
 
-		printf("\t\tdevice root gen %llu block %llu\n",
-		       (unsigned long long)btrfs_backup_dev_root_gen(backup),
-		       (unsigned long long)btrfs_backup_dev_root(backup));
+		pr_verbose(LOG_DEFAULT, "\t\tdevice root gen %llu block %llu\n",
+		       btrfs_backup_dev_root_gen(backup),
+		       btrfs_backup_dev_root(backup));
 
-		printf("\t\tcsum root gen %llu block %llu\n",
-		       (unsigned long long)btrfs_backup_csum_root_gen(backup),
-		       (unsigned long long)btrfs_backup_csum_root(backup));
+		pr_verbose(LOG_DEFAULT, "\t\tcsum root gen %llu block %llu\n",
+		       btrfs_backup_csum_root_gen(backup),
+		       btrfs_backup_csum_root(backup));
 
-		printf("\t\tfs root gen %llu block %llu\n",
-		       (unsigned long long)btrfs_backup_fs_root_gen(backup),
-		       (unsigned long long)btrfs_backup_fs_root(backup));
+		pr_verbose(LOG_DEFAULT, "\t\tfs root gen %llu block %llu\n",
+		       btrfs_backup_fs_root_gen(backup),
+		       btrfs_backup_fs_root(backup));
 
-		printf("\t\t%llu used %llu total %llu devices\n",
-		       (unsigned long long)btrfs_backup_bytes_used(backup),
-		       (unsigned long long)btrfs_backup_total_bytes(backup),
-		       (unsigned long long)btrfs_backup_num_devices(backup));
+		pr_verbose(LOG_DEFAULT, "\t\t%llu used %llu total %llu devices\n",
+		       btrfs_backup_bytes_used(backup),
+		       btrfs_backup_total_bytes(backup),
+		       btrfs_backup_num_devices(backup));
 	}
 }
 
@@ -315,11 +321,11 @@ static int cmd_inspect_dump_tree(const struct cmd_struct *cmd,
 	char uuidbuf[BTRFS_UUID_UNPARSED_SIZE];
 	int ret = 0;
 	int slot;
-	int extent_only = 0;
-	int device_only = 0;
-	int uuid_tree_only = 0;
-	int roots_only = 0;
-	int root_backups = 0;
+	bool extent_only = false;
+	bool device_only = false;
+	bool uuid_tree_only = false;
+	bool roots_only = false;
+	bool root_backups = false;
 	int traverse = BTRFS_PRINT_TREE_DEFAULT;
 	int dev_optind;
 	unsigned open_ctree_flags;
@@ -370,20 +376,20 @@ static int cmd_inspect_dump_tree(const struct cmd_struct *cmd,
 			break;
 		switch (c) {
 		case 'e':
-			extent_only = 1;
+			extent_only = true;
 			break;
 		case 'd':
-			device_only = 1;
+			device_only = true;
 			break;
 		case 'r':
-			roots_only = 1;
+			roots_only = true;
 			break;
 		case 'u':
-			uuid_tree_only = 1;
+			uuid_tree_only = true;
 			break;
 		case 'R':
-			roots_only = 1;
-			root_backups = 1;
+			roots_only = true;
+			root_backups = true;
 			break;
 		case 'b':
 			/*
@@ -480,7 +486,7 @@ static int cmd_inspect_dump_tree(const struct cmd_struct *cmd,
 		dev_optind++;
 	}
 
-	printf("%s\n", PACKAGE_STRING);
+	pr_verbose(LOG_DEFAULT, "%s\n", PACKAGE_STRING);
 
 	ocf.filename = argv[optind];
 	ocf.flags = open_ctree_flags;
@@ -506,46 +512,35 @@ static int cmd_inspect_dump_tree(const struct cmd_struct *cmd,
 
 	if (!(extent_only || uuid_tree_only || tree_id)) {
 		if (roots_only) {
-			printf("root tree: %llu level %d\n",
-			     (unsigned long long)info->tree_root->node->start,
+			pr_verbose(LOG_DEFAULT, "root tree: %llu level %d\n",
+			     info->tree_root->node->start,
 			     btrfs_header_level(info->tree_root->node));
-			printf("chunk tree: %llu level %d\n",
-			     (unsigned long long)info->chunk_root->node->start,
+			pr_verbose(LOG_DEFAULT, "chunk tree: %llu level %d\n",
+			     info->chunk_root->node->start,
 			     btrfs_header_level(info->chunk_root->node));
 			if (info->log_root_tree)
-				printf("log root tree: %llu level %d\n",
+				pr_verbose(LOG_DEFAULT, "log root tree: %llu level %d\n",
 				       info->log_root_tree->node->start,
 					btrfs_header_level(
 						info->log_root_tree->node));
-			if (info->block_group_root)
-				printf("block group tree: %llu level %d\n",
-				       info->block_group_root->node->start,
-					btrfs_header_level(
-						info->block_group_root->node));
 		} else {
 			if (info->tree_root->node) {
-				printf("root tree\n");
+				pr_verbose(LOG_DEFAULT, "root tree\n");
 				btrfs_print_tree(info->tree_root->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 			}
 
 			if (info->chunk_root->node) {
-				printf("chunk tree\n");
+				pr_verbose(LOG_DEFAULT, "chunk tree\n");
 				btrfs_print_tree(info->chunk_root->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 			}
 
 			if (info->log_root_tree) {
-				printf("log root tree\n");
+				pr_verbose(LOG_DEFAULT, "log root tree\n");
 				btrfs_print_tree(info->log_root_tree->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 			}
-
-			if (info->block_group_root) {
-				printf("block group tree\n");
-				btrfs_print_tree(info->block_group_root->node,
-					BTRFS_PRINT_TREE_FOLLOW | print_mode);
-			}
 		}
 	}
 	tree_root_scan = info->tree_root;
@@ -563,7 +558,7 @@ again:
 			error("cannot print root tree, invalid pointer");
 			goto close_root;
 		}
-		printf("root tree\n");
+		pr_verbose(LOG_DEFAULT, "root tree\n");
 		btrfs_print_tree(info->tree_root->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 		goto close_root;
@@ -574,7 +569,7 @@ again:
 			error("cannot print chunk tree, invalid pointer");
 			goto close_root;
 		}
-		printf("chunk tree\n");
+		pr_verbose(LOG_DEFAULT, "chunk tree\n");
 		btrfs_print_tree(info->chunk_root->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 		goto close_root;
@@ -585,7 +580,7 @@ again:
 			error("cannot print log root tree, invalid pointer");
 			goto close_root;
 		}
-		printf("log root tree\n");
+		pr_verbose(LOG_DEFAULT, "log root tree\n");
 		btrfs_print_tree(info->log_root_tree->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 		goto close_root;
@@ -596,7 +591,7 @@ again:
 			error("cannot print block group tree, invalid pointer");
 			goto close_root;
 		}
-		printf("block group tree\n");
+		pr_verbose(LOG_DEFAULT, "block group tree\n");
 		btrfs_print_tree(info->block_group_root->node,
 					BTRFS_PRINT_TREE_FOLLOW | print_mode);
 		goto close_root;
@@ -609,7 +604,7 @@ again:
 	if (ret < 0) {
 		errno = -ret;
 		error("cannot read ROOT_ITEM from tree %llu: %m",
-			(unsigned long long)tree_root_scan->root_key.objectid);
+			tree_root_scan->root_key.objectid);
 		goto close_root;
 	}
 	while (1) {
@@ -627,7 +622,7 @@ again:
 		if (found_key.type == BTRFS_ROOT_ITEM_KEY) {
 			unsigned long offset;
 			struct extent_buffer *buf;
-			int skip = extent_only | device_only | uuid_tree_only;
+			bool skip = (extent_only || device_only || uuid_tree_only);
 
 			offset = btrfs_item_ptr_offset(leaf, slot);
 			read_extent_buffer(leaf, &ri, offset, sizeof(ri));
@@ -642,112 +637,111 @@ again:
 			switch (found_key.objectid) {
 			case BTRFS_ROOT_TREE_OBJECTID:
 				if (!skip)
-					printf("root");
+					pr_verbose(LOG_DEFAULT, "root");
 				break;
 			case BTRFS_EXTENT_TREE_OBJECTID:
 				if (!device_only && !uuid_tree_only)
 					skip = 0;
 				if (!skip)
-					printf("extent");
+					pr_verbose(LOG_DEFAULT, "extent");
 				break;
 			case BTRFS_CHUNK_TREE_OBJECTID:
 				if (!skip) {
-					printf("chunk");
+					pr_verbose(LOG_DEFAULT, "chunk");
 				}
 				break;
 			case BTRFS_DEV_TREE_OBJECTID:
 				if (!uuid_tree_only)
 					skip = 0;
 				if (!skip)
-					printf("device");
+					pr_verbose(LOG_DEFAULT, "device");
 				break;
 			case BTRFS_FS_TREE_OBJECTID:
 				if (!skip) {
-					printf("fs");
+					pr_verbose(LOG_DEFAULT, "fs");
 				}
 				break;
 			case BTRFS_ROOT_TREE_DIR_OBJECTID:
 				skip = 0;
-				printf("directory");
+				pr_verbose(LOG_DEFAULT, "directory");
 				break;
 			case BTRFS_CSUM_TREE_OBJECTID:
 				if (!skip) {
-					printf("checksum");
+					pr_verbose(LOG_DEFAULT, "checksum");
 				}
 				break;
 			case BTRFS_ORPHAN_OBJECTID:
 				if (!skip) {
-					printf("orphan");
+					pr_verbose(LOG_DEFAULT, "orphan");
 				}
 				break;
 			case BTRFS_TREE_LOG_OBJECTID:
 				if (!skip) {
-					printf("log");
+					pr_verbose(LOG_DEFAULT, "log");
 				}
 				break;
 			case BTRFS_TREE_LOG_FIXUP_OBJECTID:
 				if (!skip) {
-					printf("log fixup");
+					pr_verbose(LOG_DEFAULT, "log fixup");
 				}
 				break;
 			case BTRFS_TREE_RELOC_OBJECTID:
 				if (!skip) {
-					printf("reloc");
+					pr_verbose(LOG_DEFAULT, "reloc");
 				}
 				break;
 			case BTRFS_DATA_RELOC_TREE_OBJECTID:
 				if (!skip) {
-					printf("data reloc");
+					pr_verbose(LOG_DEFAULT, "data reloc");
 				}
 				break;
 			case BTRFS_EXTENT_CSUM_OBJECTID:
 				if (!skip) {
-					printf("extent checksum");
+					pr_verbose(LOG_DEFAULT, "extent checksum");
 				}
 				break;
 			case BTRFS_QUOTA_TREE_OBJECTID:
 				if (!skip) {
-					printf("quota");
+					pr_verbose(LOG_DEFAULT, "quota");
 				}
 				break;
 			case BTRFS_UUID_TREE_OBJECTID:
 				if (!extent_only && !device_only)
 					skip = 0;
 				if (!skip)
-					printf("uuid");
+					pr_verbose(LOG_DEFAULT, "uuid");
 				break;
 			case BTRFS_FREE_SPACE_TREE_OBJECTID:
 				if (!skip)
-					printf("free space");
+					pr_verbose(LOG_DEFAULT, "free space");
 				break;
 			case BTRFS_MULTIPLE_OBJECTIDS:
 				if (!skip) {
-					printf("multiple");
+					pr_verbose(LOG_DEFAULT, "multiple");
 				}
 				break;
 			case BTRFS_BLOCK_GROUP_TREE_OBJECTID:
 				if (!skip)
-					printf("block group");
+					pr_verbose(LOG_DEFAULT, "block group");
 				break;
 			default:
 				if (!skip) {
-					printf("file");
+					pr_verbose(LOG_DEFAULT, "file");
 				}
 			}
 			if (extent_only && !skip) {
-				printf(" tree ");
+				pr_verbose(LOG_DEFAULT, " tree ");
 				btrfs_print_key(&disk_key);
-				printf("\n");
+				pr_verbose(LOG_DEFAULT, "\n");
 				print_extents(buf);
 			} else if (!skip) {
-				printf(" tree ");
+				pr_verbose(LOG_DEFAULT, " tree ");
 				btrfs_print_key(&disk_key);
 				if (roots_only) {
-					printf(" %llu level %d\n",
-					       (unsigned long long)buf->start,
-					       btrfs_header_level(buf));
+					pr_verbose(LOG_DEFAULT, " %llu level %d\n",
+					       buf->start, btrfs_header_level(buf));
 				} else {
-					printf(" \n");
+					pr_verbose(LOG_DEFAULT, " \n");
 					btrfs_print_tree(buf,
 						BTRFS_PRINT_TREE_FOLLOW | print_mode);
 				}
@@ -771,13 +765,13 @@ no_node:
 	if (root_backups)
 		print_old_roots(info->super_copy);
 
-	printf("total bytes %llu\n",
-	       (unsigned long long)btrfs_super_total_bytes(info->super_copy));
-	printf("bytes used %llu\n",
-	       (unsigned long long)btrfs_super_bytes_used(info->super_copy));
+	pr_verbose(LOG_DEFAULT, "total bytes %llu\n",
+	       btrfs_super_total_bytes(info->super_copy));
+	pr_verbose(LOG_DEFAULT, "bytes used %llu\n",
+	       btrfs_super_bytes_used(info->super_copy));
 	uuidbuf[BTRFS_UUID_UNPARSED_SIZE - 1] = '\0';
 	uuid_unparse(info->super_copy->fsid, uuidbuf);
-	printf("uuid %s\n", uuidbuf);
+	pr_verbose(LOG_DEFAULT, "uuid %s\n", uuidbuf);
 close_root:
 	ret = close_ctree(root);
 out:
