@@ -17,15 +17,17 @@
  */
 
 #include <sys/ioctl.h>
-#include <unistd.h>
-
-#include "kernel-shared/ctree.h"
-#include "ioctl.h"
-
-#include "cmds/commands.h"
-#include "common/utils.h"
+#include <dirent.h>
+#include <errno.h>
+#include <getopt.h>
+#include <stdio.h>
+#include <string.h>
+#include <stdbool.h>
 #include "common/help.h"
 #include "common/open-utils.h"
+#include "common/messages.h"
+#include "cmds/commands.h"
+#include "ioctl.h"
 
 static const char * const quota_cmd_group_usage[] = {
 	"btrfs quota <command> [options] <path>",
@@ -123,7 +125,7 @@ static int cmd_quota_rescan(const struct cmd_struct *cmd, int argc, char **argv)
 	struct btrfs_ioctl_quota_rescan_args args;
 	unsigned long ioctlnum = BTRFS_IOC_QUOTA_RESCAN;
 	DIR *dirstream = NULL;
-	int wait_for_completion = 0;
+	bool wait_for_completion = false;
 
 	optind = 0;
 	while (1) {
@@ -135,7 +137,7 @@ static int cmd_quota_rescan(const struct cmd_struct *cmd, int argc, char **argv)
 			ioctlnum = BTRFS_IOC_QUOTA_RESCAN_STATUS;
 			break;
 		case 'w':
-			wait_for_completion = 1;
+			wait_for_completion = true;
 			break;
 		default:
 			usage_unknown_option(cmd, argv);
@@ -167,15 +169,15 @@ static int cmd_quota_rescan(const struct cmd_struct *cmd, int argc, char **argv)
 			return 1;
 		}
 		if (!args.flags)
-			printf("no rescan operation in progress\n");
+			pr_verbose(LOG_DEFAULT, "no rescan operation in progress\n");
 		else
-			printf("rescan operation running (current key %lld)\n",
+			pr_verbose(LOG_DEFAULT, "rescan operation running (current key %lld)\n",
 				args.progress);
 		return 0;
 	}
 
 	if (ret == 0) {
-		pr_verbose(MUST_LOG, "quota rescan started\n");
+		pr_verbose(LOG_DEFAULT, "quota rescan started\n");
 		fflush(stdout);
 	} else if (ret < 0 && (!wait_for_completion || e != EINPROGRESS)) {
 		error("quota rescan failed: %m");
